/*******************************************************************************
* File Name: .h
* Version 3.30
*
* Description:
*  This file provides private constants and parameter values for the I2C
*  component.
*
* Note:
*
********************************************************************************
* Copyright 2012, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_I2C_PVT_Temp_Sensor_H)
#define CY_I2C_PVT_Temp_Sensor_H

#include "Temp_Sensor.h"

#define Temp_Sensor_TIMEOUT_ENABLED_INC    (0u)
#if(0u != Temp_Sensor_TIMEOUT_ENABLED_INC)
    #include "Temp_Sensor_TMOUT.h"
#endif /* (0u != Temp_Sensor_TIMEOUT_ENABLED_INC) */


/**********************************
*   Variables with external linkage
**********************************/

extern Temp_Sensor_BACKUP_STRUCT Temp_Sensor_backup;

extern volatile uint8 Temp_Sensor_state;   /* Current state of I2C FSM */

/* Master variables */
#if(Temp_Sensor_MODE_MASTER_ENABLED)
    extern volatile uint8 Temp_Sensor_mstrStatus;   /* Master Status byte  */
    extern volatile uint8 Temp_Sensor_mstrControl;  /* Master Control byte */

    /* Transmit buffer variables */
    extern volatile uint8 * Temp_Sensor_mstrRdBufPtr;   /* Pointer to Master Read buffer */
    extern volatile uint8   Temp_Sensor_mstrRdBufSize;  /* Master Read buffer size       */
    extern volatile uint8   Temp_Sensor_mstrRdBufIndex; /* Master Read buffer Index      */

    /* Receive buffer variables */
    extern volatile uint8 * Temp_Sensor_mstrWrBufPtr;   /* Pointer to Master Write buffer */
    extern volatile uint8   Temp_Sensor_mstrWrBufSize;  /* Master Write buffer size       */
    extern volatile uint8   Temp_Sensor_mstrWrBufIndex; /* Master Write buffer Index      */

#endif /* (Temp_Sensor_MODE_MASTER_ENABLED) */

/* Slave variables */
#if(Temp_Sensor_MODE_SLAVE_ENABLED)
    extern volatile uint8 Temp_Sensor_slStatus;         /* Slave Status  */

    /* Transmit buffer variables */
    extern volatile uint8 * Temp_Sensor_slRdBufPtr;     /* Pointer to Transmit buffer  */
    extern volatile uint8   Temp_Sensor_slRdBufSize;    /* Slave Transmit buffer size  */
    extern volatile uint8   Temp_Sensor_slRdBufIndex;   /* Slave Transmit buffer Index */

    /* Receive buffer variables */
    extern volatile uint8 * Temp_Sensor_slWrBufPtr;     /* Pointer to Receive buffer  */
    extern volatile uint8   Temp_Sensor_slWrBufSize;    /* Slave Receive buffer size  */
    extern volatile uint8   Temp_Sensor_slWrBufIndex;   /* Slave Receive buffer Index */

    #if(Temp_Sensor_SW_ADRR_DECODE)
        extern volatile uint8 Temp_Sensor_slAddress;     /* Software address variable */
    #endif   /* (Temp_Sensor_SW_ADRR_DECODE) */

#endif /* (Temp_Sensor_MODE_SLAVE_ENABLED) */

#if((Temp_Sensor_FF_IMPLEMENTED) && (Temp_Sensor_WAKEUP_ENABLED))
    extern volatile uint8 Temp_Sensor_wakeupSource;
#endif /* ((Temp_Sensor_FF_IMPLEMENTED) && (Temp_Sensor_WAKEUP_ENABLED)) */


#endif /* CY_I2C_PVT_Temp_Sensor_H */


/* [] END OF FILE */
