/*******************************************************************************
* File Name: Center.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Center.h"


/*******************************************************************************
* Function Name: Center_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Center_Write(uint8 value) 
{
    uint8 staticBits = (Center_DR & (uint8)(~Center_MASK));
    Center_DR = staticBits | ((uint8)(value << Center_SHIFT) & Center_MASK);
}


/*******************************************************************************
* Function Name: Center_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void Center_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Center_0, mode);
}


/*******************************************************************************
* Function Name: Center_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Center_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Center_Read(void) 
{
    return (Center_PS & Center_MASK) >> Center_SHIFT;
}


/*******************************************************************************
* Function Name: Center_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Center_ReadDataReg(void) 
{
    return (Center_DR & Center_MASK) >> Center_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Center_INTSTAT) 

    /*******************************************************************************
    * Function Name: Center_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Center_ClearInterrupt(void) 
    {
        return (Center_INTSTAT & Center_MASK) >> Center_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
