/*******************************************************************************
* File Name: Humidity.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Humidity.h"


/*******************************************************************************
* Function Name: Humidity_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Humidity_Write(uint8 value) 
{
    uint8 staticBits = (Humidity_DR & (uint8)(~Humidity_MASK));
    Humidity_DR = staticBits | ((uint8)(value << Humidity_SHIFT) & Humidity_MASK);
}


/*******************************************************************************
* Function Name: Humidity_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void Humidity_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Humidity_0, mode);
}


/*******************************************************************************
* Function Name: Humidity_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Humidity_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Humidity_Read(void) 
{
    return (Humidity_PS & Humidity_MASK) >> Humidity_SHIFT;
}


/*******************************************************************************
* Function Name: Humidity_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Humidity_ReadDataReg(void) 
{
    return (Humidity_DR & Humidity_MASK) >> Humidity_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Humidity_INTSTAT) 

    /*******************************************************************************
    * Function Name: Humidity_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Humidity_ClearInterrupt(void) 
    {
        return (Humidity_INTSTAT & Humidity_MASK) >> Humidity_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
