/*******************************************************************************
* File Name: Temp_Sensor.h
* Version 3.30
*
* Description:
*  This file provides constants and parameter values for the I2C component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_I2C_Temp_Sensor_H)
#define CY_I2C_Temp_Sensor_H

#include "cyfitter.h"
#include "cytypes.h"
#include "CyLib.h"

/* Check if required defines such as CY_PSOC5LP are available in cy_boot */
#if !defined (CY_PSOC5LP)
    #error Component I2C_v3_30 requires cy_boot v3.10 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define Temp_Sensor_IMPLEMENTATION     (1u)
#define Temp_Sensor_MODE               (2u)
#define Temp_Sensor_ENABLE_WAKEUP      (0u)
#define Temp_Sensor_ADDR_DECODE        (1u)
#define Temp_Sensor_UDB_INTRN_CLOCK    (0u)


/* I2C implementation enum */
#define Temp_Sensor_UDB    (0x00u)
#define Temp_Sensor_FF     (0x01u)

#define Temp_Sensor_FF_IMPLEMENTED     (Temp_Sensor_FF  == Temp_Sensor_IMPLEMENTATION)
#define Temp_Sensor_UDB_IMPLEMENTED    (Temp_Sensor_UDB == Temp_Sensor_IMPLEMENTATION)

#define Temp_Sensor_UDB_INTRN_CLOCK_ENABLED    (Temp_Sensor_UDB_IMPLEMENTED && \
                                                     (0u != Temp_Sensor_UDB_INTRN_CLOCK))
/* I2C modes enum */
#define Temp_Sensor_MODE_SLAVE                 (0x01u)
#define Temp_Sensor_MODE_MASTER                (0x02u)
#define Temp_Sensor_MODE_MULTI_MASTER          (0x06u)
#define Temp_Sensor_MODE_MULTI_MASTER_SLAVE    (0x07u)
#define Temp_Sensor_MODE_MULTI_MASTER_MASK     (0x04u)

#define Temp_Sensor_MODE_SLAVE_ENABLED         (0u != (Temp_Sensor_MODE_SLAVE  & Temp_Sensor_MODE))
#define Temp_Sensor_MODE_MASTER_ENABLED        (0u != (Temp_Sensor_MODE_MASTER & Temp_Sensor_MODE))
#define Temp_Sensor_MODE_MULTI_MASTER_ENABLED  (0u != (Temp_Sensor_MODE_MULTI_MASTER_MASK & \
                                                            Temp_Sensor_MODE))
#define Temp_Sensor_MODE_MULTI_MASTER_SLAVE_ENABLED    (Temp_Sensor_MODE_MULTI_MASTER_SLAVE == \
                                                             Temp_Sensor_MODE)

/* Address detection enum */
#define Temp_Sensor_SW_DECODE      (0x00u)
#define Temp_Sensor_HW_DECODE      (0x01u)

#define Temp_Sensor_SW_ADRR_DECODE             (Temp_Sensor_SW_DECODE == Temp_Sensor_ADDR_DECODE)
#define Temp_Sensor_HW_ADRR_DECODE             (Temp_Sensor_HW_DECODE == Temp_Sensor_ADDR_DECODE)

/* Wakeup enabled */
#define Temp_Sensor_WAKEUP_ENABLED             (0u != Temp_Sensor_ENABLE_WAKEUP)

/* Adds bootloader APIs to component */
#define Temp_Sensor_BOOTLOADER_INTERFACE_ENABLED   (Temp_Sensor_MODE_SLAVE_ENABLED && \
                                                            ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Temp_Sensor) || \
                                                             (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface)))

/* Timeout functionality */
#define Temp_Sensor_TIMEOUT_ENABLE             (0u)
#define Temp_Sensor_TIMEOUT_SCL_TMOUT_ENABLE   (0u)
#define Temp_Sensor_TIMEOUT_SDA_TMOUT_ENABLE   (0u)
#define Temp_Sensor_TIMEOUT_PRESCALER_ENABLE   (0u)
#define Temp_Sensor_TIMEOUT_IMPLEMENTATION     (0u)

/* Convert to boolean */
#define Temp_Sensor_TIMEOUT_ENABLED            (0u != Temp_Sensor_TIMEOUT_ENABLE)
#define Temp_Sensor_TIMEOUT_SCL_TMOUT_ENABLED  (0u != Temp_Sensor_TIMEOUT_SCL_TMOUT_ENABLE)
#define Temp_Sensor_TIMEOUT_SDA_TMOUT_ENABLED  (0u != Temp_Sensor_TIMEOUT_SDA_TMOUT_ENABLE)
#define Temp_Sensor_TIMEOUT_PRESCALER_ENABLED  (0u != Temp_Sensor_TIMEOUT_PRESCALER_ENABLE)

/* Timeout implementation enum. */
#define Temp_Sensor_TIMEOUT_UDB    (0x00u)
#define Temp_Sensor_TIMEOUT_FF     (0x01u)

#define Temp_Sensor_TIMEOUT_FF_IMPLEMENTED     (Temp_Sensor_TIMEOUT_FF  == \
                                                        Temp_Sensor_TIMEOUT_IMPLEMENTATION)
#define Temp_Sensor_TIMEOUT_UDB_IMPLEMENTED    (Temp_Sensor_TIMEOUT_UDB == \
                                                        Temp_Sensor_TIMEOUT_IMPLEMENTATION)

#define Temp_Sensor_TIMEOUT_FF_ENABLED         (Temp_Sensor_TIMEOUT_ENABLED && \
                                                     Temp_Sensor_TIMEOUT_FF_IMPLEMENTED && \
                                                     CY_PSOC5LP)

#define Temp_Sensor_TIMEOUT_UDB_ENABLED        (Temp_Sensor_TIMEOUT_ENABLED && \
                                                     Temp_Sensor_TIMEOUT_UDB_IMPLEMENTED)

#define Temp_Sensor_EXTERN_I2C_INTR_HANDLER    (0u)
#define Temp_Sensor_EXTERN_TMOUT_INTR_HANDLER  (0u)

#define Temp_Sensor_INTERN_I2C_INTR_HANDLER    (0u == Temp_Sensor_EXTERN_I2C_INTR_HANDLER)
#define Temp_Sensor_INTERN_TMOUT_INTR_HANDLER  (0u == Temp_Sensor_EXTERN_TMOUT_INTR_HANDLER)


/***************************************
*       Type defines
***************************************/

/* Structure to save registers before go to sleep */
typedef struct
{
    uint8 enableState;

    #if(Temp_Sensor_FF_IMPLEMENTED)
        uint8 xcfg;
        uint8 cfg;

        #if(Temp_Sensor_MODE_SLAVE_ENABLED)
            uint8 addr;
        #endif /* (Temp_Sensor_MODE_SLAVE_ENABLED) */

        #if(CY_PSOC5A)
            uint8 clkDiv;
        #else
            uint8 clkDiv1;
            uint8 clkDiv2;
        #endif /* (CY_PSOC5A) */

    #else
        uint8 control;

        #if(CY_UDB_V0)
            uint8 intMask;

            #if(Temp_Sensor_MODE_SLAVE_ENABLED)
                uint8 addr;
            #endif /* (Temp_Sensor_MODE_SLAVE_ENABLED) */
        #endif     /* (CY_UDB_V0) */

    #endif /* (Temp_Sensor_FF_IMPLEMENTED) */

    #if(Temp_Sensor_TIMEOUT_ENABLED)
        uint16 tmoutCfg;
        uint8  tmoutIntr;

        #if(Temp_Sensor_TIMEOUT_PRESCALER_ENABLED && CY_UDB_V0)
            uint8 tmoutPrd;
        #endif /* (Temp_Sensor_TIMEOUT_PRESCALER_ENABLED && CY_UDB_V0) */

    #endif /* (Temp_Sensor_TIMEOUT_ENABLED) */

} Temp_Sensor_BACKUP_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

void Temp_Sensor_Init(void)                            ;
void Temp_Sensor_Enable(void)                          ;

void Temp_Sensor_Start(void)                           ;
void Temp_Sensor_Stop(void)                            ;

#define Temp_Sensor_EnableInt()        CyIntEnable      (Temp_Sensor_ISR_NUMBER)
#define Temp_Sensor_DisableInt()       CyIntDisable     (Temp_Sensor_ISR_NUMBER)
#define Temp_Sensor_ClearPendingInt()  CyIntClearPending(Temp_Sensor_ISR_NUMBER)
#define Temp_Sensor_SetPendingInt()    CyIntSetPending  (Temp_Sensor_ISR_NUMBER)

void Temp_Sensor_SaveConfig(void)                      ;
void Temp_Sensor_Sleep(void)                           ;
void Temp_Sensor_RestoreConfig(void)                   ;
void Temp_Sensor_Wakeup(void)                          ;

/* I2C Master functions prototypes */
#if(Temp_Sensor_MODE_MASTER_ENABLED)
    /* Read and Clear status functions */
    uint8 Temp_Sensor_MasterStatus(void)                ;
    uint8 Temp_Sensor_MasterClearStatus(void)           ;

    /* Interrupt based operation functions */
    uint8 Temp_Sensor_MasterWriteBuf(uint8 slaveAddress, uint8 * wrData, uint8 cnt, uint8 mode) \
                                                            ;
    uint8 Temp_Sensor_MasterReadBuf(uint8 slaveAddress, uint8 * rdData, uint8 cnt, uint8 mode) \
                                                            ;
    uint8 Temp_Sensor_MasterGetReadBufSize(void)       ;
    uint8 Temp_Sensor_MasterGetWriteBufSize(void)      ;
    void  Temp_Sensor_MasterClearReadBuf(void)         ;
    void  Temp_Sensor_MasterClearWriteBuf(void)        ;

    /* Manual operation functions */
    uint8 Temp_Sensor_MasterSendStart(uint8 slaveAddress, uint8 R_nW) \
                                                            ;
    uint8 Temp_Sensor_MasterSendRestart(uint8 slaveAddress, uint8 R_nW) \
                                                            ;
    uint8 Temp_Sensor_MasterSendStop(void)             ;
    uint8 Temp_Sensor_MasterWriteByte(uint8 theByte)   ;
    uint8 Temp_Sensor_MasterReadByte(uint8 acknNak)    ;

    /* This fake function use as workaround */
    void  Temp_Sensor_Workaround(void)                 ;

#endif /* (Temp_Sensor_MODE_MASTER_ENABLED) */

/* I2C Slave functions prototypes */
#if(Temp_Sensor_MODE_SLAVE_ENABLED)
    /* Read and Clear status functions */
    uint8 Temp_Sensor_SlaveStatus(void)                ;
    uint8 Temp_Sensor_SlaveClearReadStatus(void)       ;
    uint8 Temp_Sensor_SlaveClearWriteStatus(void)      ;

    void  Temp_Sensor_SlaveSetAddress(uint8 address)   ;

    /* Interrupt based operation functions */
    void  Temp_Sensor_SlaveInitReadBuf(uint8 * rdBuf, uint8 bufSize) \
                                                            ;
    void  Temp_Sensor_SlaveInitWriteBuf(uint8 * wrBuf, uint8 bufSize) \
                                                            ;
    uint8 Temp_Sensor_SlaveGetReadBufSize(void)        ;
    uint8 Temp_Sensor_SlaveGetWriteBufSize(void)       ;
    void  Temp_Sensor_SlaveClearReadBuf(void)          ;
    void  Temp_Sensor_SlaveClearWriteBuf(void)         ;

    /* Communication bootloader I2C Slave APIs */
    #if defined(CYDEV_BOOTLOADER_IO_COMP) && (Temp_Sensor_BOOTLOADER_INTERFACE_ENABLED)
        /* Physical layer functions */
        void     Temp_Sensor_CyBtldrCommStart(void) CYSMALL \
                                                            ;
        void     Temp_Sensor_CyBtldrCommStop(void)  CYSMALL \
                                                            ;
        void     Temp_Sensor_CyBtldrCommReset(void) CYSMALL \
                                                            ;
        cystatus Temp_Sensor_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) \
                                                        CYSMALL ;
        cystatus Temp_Sensor_CyBtldrCommRead(uint8 pData[], uint16 size, uint16 * count, uint8 timeOut)  CYSMALL \
                                                            ;

        #if(CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Temp_Sensor)
            #define CyBtldrCommStart    Temp_Sensor_CyBtldrCommStart
            #define CyBtldrCommStop     Temp_Sensor_CyBtldrCommStop
            #define CyBtldrCommReset    Temp_Sensor_CyBtldrCommReset
            #define CyBtldrCommWrite    Temp_Sensor_CyBtldrCommWrite
            #define CyBtldrCommRead     Temp_Sensor_CyBtldrCommRead
        #endif /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Temp_Sensor) */

        /* Size of Read/Write buffers for I2C bootloader  */
        #define Temp_Sensor_BTLDR_SIZEOF_READ_BUFFER   (0x80u)
        #define Temp_Sensor_BTLDR_SIZEOF_WRITE_BUFFER  (0x80u)
        #define Temp_Sensor_MIN_UNT16(a, b)            ( ((uint16)(a) < (b)) ? ((uint16) (a)) : ((uint16) (b)) )
        #define Temp_Sensor_WAIT_1_MS                  (1u)

    #endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (Temp_Sensor_BOOTLOADER_INTERFACE_ENABLED) */

#endif /* (Temp_Sensor_MODE_SLAVE_ENABLED) */

/* I2C interrupt handler */
CY_ISR_PROTO(Temp_Sensor_ISR);
#if((Temp_Sensor_FF_IMPLEMENTED) || (Temp_Sensor_WAKEUP_ENABLED))
    CY_ISR_PROTO(Temp_Sensor_WAKEUP_ISR);
#endif /* ((Temp_Sensor_FF_IMPLEMENTED) || (Temp_Sensor_WAKEUP_ENABLED)) */


/**********************************
*   Variable with external linkage
**********************************/

extern uint8 Temp_Sensor_initVar;


/***************************************
*   Initial Parameter Constants
***************************************/

#define Temp_Sensor_DATA_RATE          (100u)
#define Temp_Sensor_DEFAULT_ADDR       (8u)
#define Temp_Sensor_I2C_PAIR_SELECTED  (0u)

/* I2C pair enum */
#define Temp_Sensor_I2C_PAIR_ANY   (0x01u) /* Any pins for I2C */
#define Temp_Sensor_I2C_PAIR0      (0x01u) /* I2C0: (SCL = P12[4]) && (SCL = P12[5]) */
#define Temp_Sensor_I2C_PAIR1      (0x02u) /* I2C1: (SCL = P12[0]) && (SDA = P12[1]) */

#define Temp_Sensor_I2C1_SIO_PAIR  (Temp_Sensor_I2C_PAIR1 == Temp_Sensor_I2C_PAIR_SELECTED)
#define Temp_Sensor_I2C0_SIO_PAIR  (Temp_Sensor_I2C_PAIR0 == Temp_Sensor_I2C_PAIR_SELECTED)


/***************************************
*            API Constants
***************************************/

/* Master/Slave control constants */
#define Temp_Sensor_READ_XFER_MODE     (0x01u) /* Read */
#define Temp_Sensor_WRITE_XFER_MODE    (0x00u) /* Write */
#define Temp_Sensor_ACK_DATA           (0x01u) /* Send ACK */
#define Temp_Sensor_NAK_DATA           (0x00u) /* Send NAK */
#define Temp_Sensor_OVERFLOW_RETURN    (0xFFu) /* Senf on bus in case of overflow */

#if(Temp_Sensor_MODE_MASTER_ENABLED)
    /* "Mode" constants for MasterWriteBuf() or MasterReadBuf() function */
    #define Temp_Sensor_MODE_COMPLETE_XFER     (0x00u) /* Full transfer with Start and Stop */
    #define Temp_Sensor_MODE_REPEAT_START      (0x01u) /* Begin with a ReStart instead of a Start */
    #define Temp_Sensor_MODE_NO_STOP           (0x02u) /* Complete the transfer without a Stop */

    /* Master status */
    #define Temp_Sensor_MSTAT_CLEAR            (0x00u) /* Clear (init) status value */

    #define Temp_Sensor_MSTAT_RD_CMPLT         (0x01u) /* Read complete */
    #define Temp_Sensor_MSTAT_WR_CMPLT         (0x02u) /* Write complete */
    #define Temp_Sensor_MSTAT_XFER_INP         (0x04u) /* Master transfer in progress */
    #define Temp_Sensor_MSTAT_XFER_HALT        (0x08u) /* Transfer is halted */

    #define Temp_Sensor_MSTAT_ERR_MASK         (0xF0u) /* Mask for all errors */
    #define Temp_Sensor_MSTAT_ERR_SHORT_XFER   (0x10u) /* Master NAKed before end of packet */
    #define Temp_Sensor_MSTAT_ERR_ADDR_NAK     (0x20u) /* Slave did not ACK */
    #define Temp_Sensor_MSTAT_ERR_ARB_LOST     (0x40u) /* Master lost arbitration during communication */
    #define Temp_Sensor_MSTAT_ERR_XFER         (0x80u) /* Error during transfer */

    /* Master API returns */
    #define Temp_Sensor_MSTR_NO_ERROR          (0x00u) /* Function complete without error */
    #define Temp_Sensor_MSTR_BUS_BUSY          (0x01u) /* Bus is busy, process not started */
    #define Temp_Sensor_MSTR_NOT_READY         (0x02u) /* Master not Master on the bus or */
                                                            /*  Slave operation in progress */
    #define Temp_Sensor_MSTR_ERR_LB_NAK        (0x03u) /* Last Byte Naked */
    #define Temp_Sensor_MSTR_ERR_ARB_LOST      (0x04u) /* Master lost arbitration during communication */
    #define Temp_Sensor_MSTR_ERR_ABORT_START_GEN  (0x05u) /* Master did not generate Start, the Slave */
                                                               /* was addressed before */

#endif /* (Temp_Sensor_MODE_MASTER_ENABLED) */

#if(Temp_Sensor_MODE_SLAVE_ENABLED)
    /* Slave Status Constants */
    #define Temp_Sensor_SSTAT_RD_CMPLT     (0x01u) /* Read transfer complete */
    #define Temp_Sensor_SSTAT_RD_BUSY      (0x02u) /* Read transfer in progress */
    #define Temp_Sensor_SSTAT_RD_ERR_OVFL  (0x04u) /* Read overflow Error */
    #define Temp_Sensor_SSTAT_RD_MASK      (0x0Fu) /* Read Status Mask */
    #define Temp_Sensor_SSTAT_RD_NO_ERR    (0x00u) /* Read no Error */

    #define Temp_Sensor_SSTAT_WR_CMPLT     (0x10u) /* Write transfer complete */
    #define Temp_Sensor_SSTAT_WR_BUSY      (0x20u) /* Write transfer in progress */
    #define Temp_Sensor_SSTAT_WR_ERR_OVFL  (0x40u) /* Write overflow Error */
    #define Temp_Sensor_SSTAT_WR_MASK      (0xF0u) /* Write Status Mask  */
    #define Temp_Sensor_SSTAT_WR_NO_ERR    (0x00u) /* Write no Error */

    #define Temp_Sensor_SSTAT_RD_CLEAR     (0x0Du) /* Read Status clear */
    #define Temp_Sensor_SSTAT_WR_CLEAR     (0xD0u) /* Write Status Clear */

#endif /* (Temp_Sensor_MODE_SLAVE_ENABLED) */


/***************************************
*       I2C state machine constants
***************************************/

/* Default slave address states */
#define  Temp_Sensor_SM_IDLE           (0x10u) /* Default state - IDLE */
#define  Temp_Sensor_SM_EXIT_IDLE      (0x00u) /* Pass master and slave processing and go to IDLE */

/* Slave mode states */
#define  Temp_Sensor_SM_SLAVE          (Temp_Sensor_SM_IDLE) /* Any Slave state */
#define  Temp_Sensor_SM_SL_WR_DATA     (0x11u) /* Master writes data to slzve  */
#define  Temp_Sensor_SM_SL_RD_DATA     (0x12u) /* Master reads data from slave */

/* Master mode states */
#define  Temp_Sensor_SM_MASTER         (0x40u) /* Any master state */

#define  Temp_Sensor_SM_MSTR_RD        (0x08u) /* Any master read state          */
#define  Temp_Sensor_SM_MSTR_RD_ADDR   (0x49u) /* Master sends address with read */
#define  Temp_Sensor_SM_MSTR_RD_DATA   (0x4Au) /* Master reads data              */

#define  Temp_Sensor_SM_MSTR_WR        (0x04u) /* Any master read state           */
#define  Temp_Sensor_SM_MSTR_WR_ADDR   (0x45u) /* Master sends address with write */
#define  Temp_Sensor_SM_MSTR_WR_DATA   (0x46u) /* Master writes data              */

#define  Temp_Sensor_SM_MSTR_HALT      (0x60u) /* Master waits for ReStart */

#define Temp_Sensor_CHECK_SM_MASTER    (0u != (Temp_Sensor_SM_MASTER & Temp_Sensor_state))
#define Temp_Sensor_CHECK_SM_SLAVE     (0u != (Temp_Sensor_SM_SLAVE  & Temp_Sensor_state))


/***************************************
*              Registers
***************************************/

#if(Temp_Sensor_FF_IMPLEMENTED)
    /* Fixed Function registers */
    #define Temp_Sensor_XCFG_REG           (* (reg8 *) Temp_Sensor_I2C_FF__XCFG)
    #define Temp_Sensor_XCFG_PTR           (  (reg8 *) Temp_Sensor_I2C_FF__XCFG)

    #define Temp_Sensor_ADDR_REG           (* (reg8 *) Temp_Sensor_I2C_FF__ADR)
    #define Temp_Sensor_ADDR_PTR           (  (reg8 *) Temp_Sensor_I2C_FF__ADR)

    #define Temp_Sensor_CFG_REG            (* (reg8 *) Temp_Sensor_I2C_FF__CFG)
    #define Temp_Sensor_CFG_PTR            (  (reg8 *) Temp_Sensor_I2C_FF__CFG)

    #define Temp_Sensor_CSR_REG            (* (reg8 *) Temp_Sensor_I2C_FF__CSR)
    #define Temp_Sensor_CSR_PTR            (  (reg8 *) Temp_Sensor_I2C_FF__CSR)

    #define Temp_Sensor_DATA_REG           (* (reg8 *) Temp_Sensor_I2C_FF__D)
    #define Temp_Sensor_DATA_PTR           (  (reg8 *) Temp_Sensor_I2C_FF__D)

    #define Temp_Sensor_MCSR_REG           (* (reg8 *) Temp_Sensor_I2C_FF__MCSR)
    #define Temp_Sensor_MCSR_PTR           (  (reg8 *) Temp_Sensor_I2C_FF__MCSR)

    #define Temp_Sensor_ACT_PWRMGR_REG     (* (reg8 *) Temp_Sensor_I2C_FF__PM_ACT_CFG)
    #define Temp_Sensor_ACT_PWRMGR_PTR     (  (reg8 *) Temp_Sensor_I2C_FF__PM_ACT_CFG)
    #define Temp_Sensor_ACT_PWR_EN         (  (uint8)  Temp_Sensor_I2C_FF__PM_ACT_MSK)

    #define Temp_Sensor_STBY_PWRMGR_REG    (* (reg8 *) Temp_Sensor_I2C_FF__PM_STBY_CFG)
    #define Temp_Sensor_STBY_PWRMGR_PTR    (  (reg8 *) Temp_Sensor_I2C_FF__PM_STBY_CFG)
    #define Temp_Sensor_STBY_PWR_EN        (  (uint8)  Temp_Sensor_I2C_FF__PM_STBY_MSK)

    #define Temp_Sensor_PWRSYS_CR1_REG     (* (reg8 *) CYREG_PWRSYS_CR1)
    #define Temp_Sensor_PWRSYS_CR1_PTR     (  (reg8 *) CYREG_PWRSYS_CR1)

    /* Clock divider register depends on silicon */
    #if(CY_PSOC5A)
        #define Temp_Sensor_CLKDIV_REG     (* (reg8 *) Temp_Sensor_I2C_FF__CLK_DIV)
        #define Temp_Sensor_CLKDIV_PTR     (  (reg8 *) Temp_Sensor_I2C_FF__CLK_DIV)

    #else
        #define Temp_Sensor_CLKDIV1_REG    (* (reg8 *) Temp_Sensor_I2C_FF__CLK_DIV1)
        #define Temp_Sensor_CLKDIV1_PTR    (  (reg8 *) Temp_Sensor_I2C_FF__CLK_DIV1)

        #define Temp_Sensor_CLKDIV2_REG    (* (reg8 *) Temp_Sensor_I2C_FF__CLK_DIV2)
        #define Temp_Sensor_CLKDIV2_PTR    (  (reg8 *) Temp_Sensor_I2C_FF__CLK_DIV2)

    #endif /* (CY_PSOC5A) */

#else
    /* UDB implementation registers */
    #define Temp_Sensor_CFG_REG    (* (reg8 *) \
                                           Temp_Sensor_bI2C_UDB_SyncCtl_CtrlReg__CONTROL_REG)
    #define Temp_Sensor_CFG_PTR    (  (reg8 *) \
                                           Temp_Sensor_bI2C_UDB_SyncCtl_CtrlReg__CONTROL_REG)

    #define Temp_Sensor_CSR_REG        (* (reg8 *) Temp_Sensor_bI2C_UDB_StsReg__STATUS_REG)
    #define Temp_Sensor_CSR_PTR        (  (reg8 *) Temp_Sensor_bI2C_UDB_StsReg__STATUS_REG)

    #define Temp_Sensor_INT_MASK_REG   (* (reg8 *) Temp_Sensor_bI2C_UDB_StsReg__MASK_REG)
    #define Temp_Sensor_INT_MASK_PTR   (  (reg8 *) Temp_Sensor_bI2C_UDB_StsReg__MASK_REG)

    #define Temp_Sensor_INT_ENABLE_REG (* (reg8 *) Temp_Sensor_bI2C_UDB_StsReg__STATUS_AUX_CTL_REG)
    #define Temp_Sensor_INT_ENABLE_PTR (  (reg8 *) Temp_Sensor_bI2C_UDB_StsReg__STATUS_AUX_CTL_REG)

    #define Temp_Sensor_DATA_REG       (* (reg8 *) Temp_Sensor_bI2C_UDB_Shifter_u0__A0_REG)
    #define Temp_Sensor_DATA_PTR       (  (reg8 *) Temp_Sensor_bI2C_UDB_Shifter_u0__A0_REG)

    #define Temp_Sensor_GO_REG         (* (reg8 *) Temp_Sensor_bI2C_UDB_Shifter_u0__F1_REG)
    #define Temp_Sensor_GO_PTR         (  (reg8 *) Temp_Sensor_bI2C_UDB_Shifter_u0__F1_REG)

    #define Temp_Sensor_MCLK_PRD_REG   (* (reg8 *) Temp_Sensor_bI2C_UDB_Master_ClkGen_u0__D0_REG)
    #define Temp_Sensor_MCLK_PRD_PTR   (  (reg8 *) Temp_Sensor_bI2C_UDB_Master_ClkGen_u0__D0_REG)

    #define Temp_Sensor_MCLK_CMP_REG   (* (reg8 *) Temp_Sensor_bI2C_UDB_Master_ClkGen_u0__D1_REG)
    #define Temp_Sensor_MCLK_CMP_PTR   (  (reg8 *) Temp_Sensor_bI2C_UDB_Master_ClkGen_u0__D1_REG)

    #if(Temp_Sensor_MODE_SLAVE_ENABLED)
        #define Temp_Sensor_ADDR_REG       (* (reg8 *) Temp_Sensor_bI2C_UDB_Shifter_u0__D0_REG)
        #define Temp_Sensor_ADDR_PTR       (  (reg8 *) Temp_Sensor_bI2C_UDB_Shifter_u0__D0_REG)

        #define Temp_Sensor_PERIOD_REG     (* (reg8 *) Temp_Sensor_bI2C_UDB_Slave_BitCounter__PERIOD_REG)
        #define Temp_Sensor_PERIOD_PTR     (  (reg8 *) Temp_Sensor_bI2C_UDB_Slave_BitCounter__PERIOD_REG)

        #define Temp_Sensor_COUNTER_REG    (* (reg8 *) Temp_Sensor_bI2C_UDB_Slave_BitCounter__COUNT_REG)
        #define Temp_Sensor_COUNTER_PTR    (  (reg8 *) Temp_Sensor_bI2C_UDB_Slave_BitCounter__COUNT_REG)

        #define Temp_Sensor_COUNTER_AUX_CTL_REG  (* (reg8 *) \
                                                        Temp_Sensor_bI2C_UDB_Slave_BitCounter__CONTROL_AUX_CTL_REG)
        #define Temp_Sensor_COUNTER_AUX_CTL_PTR  (  (reg8 *) \
                                                        Temp_Sensor_bI2C_UDB_Slave_BitCounter__CONTROL_AUX_CTL_REG)

    #endif /* (Temp_Sensor_MODE_SLAVE_ENABLED) */

#endif /* (Temp_Sensor_FF_IMPLEMENTED) */


/***************************************
*        Registers Constants
***************************************/

/* Temp_Sensor_I2C_IRQ */
#define Temp_Sensor_ISR_NUMBER     ((uint8) Temp_Sensor_I2C_IRQ__INTC_NUMBER)
#define Temp_Sensor_ISR_PRIORITY   ((uint8) Temp_Sensor_I2C_IRQ__INTC_PRIOR_NUM)

/* I2C Slave Data Register */
#define Temp_Sensor_SLAVE_ADDR_MASK    (0x7Fu)
#define Temp_Sensor_SLAVE_ADDR_SHIFT   (0x01u)
#define Temp_Sensor_DATA_MASK          (0xFFu)
#define Temp_Sensor_READ_FLAG          (0x01u)

#define Temp_Sensor_FF_RESET_DELAY     (0x02u)

#if(Temp_Sensor_FF_IMPLEMENTED)
    /* XCFG I2C Extended Configuration Register */
    #define Temp_Sensor_XCFG_CLK_EN        (0x80u) /* Enable gated clock to block */
    #define Temp_Sensor_XCFG_I2C_ON        (0x40u) /* Enable I2C as wake up source*/
    #define Temp_Sensor_XCFG_RDY_TO_SLEEP  (0x20u) /* I2C ready go to sleep */
    #define Temp_Sensor_XCFG_FORCE_NACK    (0x10u) /* Force NACK all incomming transactions */
    #define Temp_Sensor_XCFG_NO_BC_INT     (0x08u) /* No interrupt on byte complete */
    #define Temp_Sensor_XCFG_BUF_MODE      (0x02u) /* Enable buffer mode */
    #define Temp_Sensor_XCFG_HDWR_ADDR_EN  (0x01u) /* Enable Hardware address match */

    /* CFG I2C Configuration Register */
    #define Temp_Sensor_CFG_SIO_SELECT     (0x80u) /* Pin Select for SCL/SDA lines */
    #define Temp_Sensor_CFG_PSELECT        (0x40u) /* Pin Select */
    #define Temp_Sensor_CFG_BUS_ERR_IE     (0x20u) /* Bus Error Interrupt Enable */
    #define Temp_Sensor_CFG_STOP_IE        (0x10u) /* Enable Interrupt on STOP condition */
    #define Temp_Sensor_CFG_CLK_RATE_MSK   (0x0Cu) /* Clock rate select  **CHECK**  */
    #define Temp_Sensor_CFG_CLK_RATE_100   (0x00u) /* Clock rate select 100K */
    #define Temp_Sensor_CFG_CLK_RATE_400   (0x04u) /* Clock rate select 400K */
    #define Temp_Sensor_CFG_CLK_RATE_050   (0x08u) /* Clock rate select 50K  */
    #define Temp_Sensor_CFG_CLK_RATE_RSVD  (0x0Cu) /* Clock rate select Invalid */
    #define Temp_Sensor_CFG_EN_MSTR        (0x02u) /* Enable Master operation */
    #define Temp_Sensor_CFG_EN_SLAVE       (0x01u) /* Enable Slave operation */

    #define Temp_Sensor_CFG_CLK_RATE_LESS_EQUAL_50 (0x04u) /* Clock rate select <= 50kHz */
    #define Temp_Sensor_CFG_CLK_RATE_GRATER_50     (0x00u) /* Clock rate select > 50kHz */

    /* CSR I2C Control and Status Register */
    #define Temp_Sensor_CSR_BUS_ERROR      (0x80u) /* Active high when bus error has occured */
    #define Temp_Sensor_CSR_LOST_ARB       (0x40u) /* Set to 1 if lost arbitration in host mode */
    #define Temp_Sensor_CSR_STOP_STATUS    (0x20u) /* Set if Stop has been detected */
    #define Temp_Sensor_CSR_ACK            (0x10u) /* ACK response */
    #define Temp_Sensor_CSR_NAK            (0x00u) /* NAK response */
    #define Temp_Sensor_CSR_ADDRESS        (0x08u) /* Set in firmware 0 = status bit, 1 Address is slave */
    #define Temp_Sensor_CSR_TRANSMIT       (0x04u) /* Set in firmware 1 = transmit, 0 = receive */
    #define Temp_Sensor_CSR_LRB            (0x02u) /* Last received bit */
    #define Temp_Sensor_CSR_LRB_ACK        (0x00u) /* Last received bit was an ACK */
    #define Temp_Sensor_CSR_LRB_NAK        (0x02u) /* Last received bit was an NAK */
    #define Temp_Sensor_CSR_BYTE_COMPLETE  (0x01u) /* Informs that last byte has been sent */
    #define Temp_Sensor_CSR_STOP_GEN       (0x00u) /* Generate a stop condition */
    #define Temp_Sensor_CSR_RDY_TO_RD      (0x00u) /* Set to recieve mode */

    /* MCSR I2C Master Control and Status Register */
    #define Temp_Sensor_MCSR_STOP_GEN      (0x10u) /* Firmware sets this bit to initiate a Stop condition */
    #define Temp_Sensor_MCSR_BUS_BUSY      (0x08u) /* Status bit, Set at Start and cleared at Stop condition */
    #define Temp_Sensor_MCSR_MSTR_MODE     (0x04u) /* Status bit, Set at Start and cleared at Stop condition */
    #define Temp_Sensor_MCSR_RESTART_GEN   (0x02u) /* Firmware sets this bit to initiate a ReStart condition */
    #define Temp_Sensor_MCSR_START_GEN     (0x01u) /* Firmware sets this bit to initiate a Start condition */

    /* CLK_DIV I2C Clock Divide Factor Register */
    #define Temp_Sensor_CLK_DIV_MSK    (0x07u) /* Status bit, Set at Start and cleared at Stop condition */
    #define Temp_Sensor_CLK_DIV_1      (0x00u) /* Divide input clock by  1 */
    #define Temp_Sensor_CLK_DIV_2      (0x01u) /* Divide input clock by  2 */
    #define Temp_Sensor_CLK_DIV_4      (0x02u) /* Divide input clock by  4 */
    #define Temp_Sensor_CLK_DIV_8      (0x03u) /* Divide input clock by  8 */
    #define Temp_Sensor_CLK_DIV_16     (0x04u) /* Divide input clock by 16 */
    #define Temp_Sensor_CLK_DIV_32     (0x05u) /* Divide input clock by 32 */
    #define Temp_Sensor_CLK_DIV_64     (0x06u) /* Divide input clock by 64 */

    /* PWRSYS_CR1 to handle Sleep */
    #define Temp_Sensor_PWRSYS_CR1_I2C_REG_BACKUP  (0x04u) /* Enables, power to I2C regs while sleep */

#else
    /* CONTROL REG bits location */
    #define Temp_Sensor_CTRL_START_SHIFT           (7u)
    #define Temp_Sensor_CTRL_STOP_SHIFT            (6u)
    #define Temp_Sensor_CTRL_RESTART_SHIFT         (5u)
    #define Temp_Sensor_CTRL_NACK_SHIFT            (4u)
    #define Temp_Sensor_CTRL_ANY_ADDRESS_SHIFT     (3u)
    #define Temp_Sensor_CTRL_TRANSMIT_SHIFT        (2u)
    #define Temp_Sensor_CTRL_ENABLE_MASTER_SHIFT   (1u)
    #define Temp_Sensor_CTRL_ENABLE_SLAVE_SHIFT    (0u)
    #define Temp_Sensor_CTRL_START_MASK            ((uint8) (0x01u << Temp_Sensor_CTRL_START_SHIFT))
    #define Temp_Sensor_CTRL_STOP_MASK             ((uint8) (0x01u << Temp_Sensor_CTRL_STOP_SHIFT))
    #define Temp_Sensor_CTRL_RESTART_MASK          ((uint8) (0x01u << Temp_Sensor_CTRL_RESTART_SHIFT))
    #define Temp_Sensor_CTRL_NACK_MASK             ((uint8) (0x01u << Temp_Sensor_CTRL_NACK_SHIFT))
    #define Temp_Sensor_CTRL_ANY_ADDRESS_MASK      ((uint8) (0x01u << Temp_Sensor_CTRL_ANY_ADDRESS_SHIFT))
    #define Temp_Sensor_CTRL_TRANSMIT_MASK         ((uint8) (0x01u << Temp_Sensor_CTRL_TRANSMIT_SHIFT))
    #define Temp_Sensor_CTRL_ENABLE_MASTER_MASK    ((uint8) (0x01u << Temp_Sensor_CTRL_ENABLE_MASTER_SHIFT))
    #define Temp_Sensor_CTRL_ENABLE_SLAVE_MASK     ((uint8) (0x01u << Temp_Sensor_CTRL_ENABLE_SLAVE_SHIFT))

    /* STATUS REG bits location */
    #define Temp_Sensor_STS_LOST_ARB_SHIFT         (6u)
    #define Temp_Sensor_STS_STOP_SHIFT             (5u)
    #define Temp_Sensor_STS_BUSY_SHIFT             (4u)
    #define Temp_Sensor_STS_ADDR_SHIFT             (3u)
    #define Temp_Sensor_STS_MASTER_MODE_SHIFT      (2u)
    #define Temp_Sensor_STS_LRB_SHIFT              (1u)
    #define Temp_Sensor_STS_BYTE_COMPLETE_SHIFT    (0u)
    #define Temp_Sensor_STS_LOST_ARB_MASK          ((uint8) (0x01u << Temp_Sensor_STS_LOST_ARB_SHIFT))
    #define Temp_Sensor_STS_STOP_MASK              ((uint8) (0x01u << Temp_Sensor_STS_STOP_SHIFT))
    #define Temp_Sensor_STS_BUSY_MASK              ((uint8) (0x01u << Temp_Sensor_STS_BUSY_SHIFT))
    #define Temp_Sensor_STS_ADDR_MASK              ((uint8) (0x01u << Temp_Sensor_STS_ADDR_SHIFT))
    #define Temp_Sensor_STS_MASTER_MODE_MASK       ((uint8) (0x01u << Temp_Sensor_STS_MASTER_MODE_SHIFT))
    #define Temp_Sensor_STS_LRB_MASK               ((uint8) (0x01u << Temp_Sensor_STS_LRB_SHIFT))
    #define Temp_Sensor_STS_BYTE_COMPLETE_MASK     ((uint8) (0x01u << Temp_Sensor_STS_BYTE_COMPLETE_SHIFT))

    /* AUX_CTL bits definition */
    #define Temp_Sensor_COUNTER_ENABLE_MASK        (0x20u) /* Enable 7-bit counter     */
    #define Temp_Sensor_INT_ENABLE_MASK            (0x10u) /* Enable intr from statusi */
    #define Temp_Sensor_CNT7_ENABLE                (Temp_Sensor_COUNTER_ENABLE_MASK)
    #define Temp_Sensor_INTR_ENABLE                (Temp_Sensor_INT_ENABLE_MASK)

#endif /* (Temp_Sensor_FF_IMPLEMENTED) */


/***************************************
*        Marco
***************************************/

/* ACK and NACK for data and address checks */
#define Temp_Sensor_CHECK_ADDR_ACK(csr)    ((Temp_Sensor_CSR_LRB_ACK | Temp_Sensor_CSR_ADDRESS) == \
                                                 ((Temp_Sensor_CSR_LRB    | Temp_Sensor_CSR_ADDRESS) &  \
                                                  (csr)))


#define Temp_Sensor_CHECK_ADDR_NAK(csr)    ((Temp_Sensor_CSR_LRB_NAK | Temp_Sensor_CSR_ADDRESS) == \
                                                 ((Temp_Sensor_CSR_LRB    | Temp_Sensor_CSR_ADDRESS) &  \
                                                  (csr)))

#define Temp_Sensor_CHECK_DATA_ACK(csr)    (0u == ((csr) & Temp_Sensor_CSR_LRB_NAK))

/* MCSR conditions check */
#define Temp_Sensor_CHECK_BUS_FREE(mcsr)       (0u == ((mcsr) & Temp_Sensor_MCSR_BUS_BUSY))
#define Temp_Sensor_CHECK_MASTER_MODE(mcsr)    (0u != ((mcsr) & Temp_Sensor_MCSR_MSTR_MODE))

/* CSR conditions check */
#define Temp_Sensor_WAIT_BYTE_COMPLETE(csr)    (0u == ((csr) & Temp_Sensor_CSR_BYTE_COMPLETE))
#define Temp_Sensor_WAIT_STOP_COMPLETE(csr)    (0u == ((csr) & (Temp_Sensor_CSR_BYTE_COMPLETE | \
                                                                     Temp_Sensor_CSR_STOP_STATUS)))
#define Temp_Sensor_CHECK_BYTE_COMPLETE(csr)   (0u != ((csr) & Temp_Sensor_CSR_BYTE_COMPLETE))
#define Temp_Sensor_CHECK_STOP_STS(csr)        (0u != ((csr) & Temp_Sensor_CSR_STOP_STATUS))
#define Temp_Sensor_CHECK_LOST_ARB(csr)        (0u != ((csr) & Temp_Sensor_CSR_LOST_ARB))
#define Temp_Sensor_CHECK_ADDRESS_STS(csr)     (0u != ((csr) & Temp_Sensor_CSR_ADDRESS))

/* Software start and end of transaction check */
#define Temp_Sensor_CHECK_RESTART(mstrCtrl)    (0u != ((mstrCtrl) & Temp_Sensor_MODE_REPEAT_START))
#define Temp_Sensor_CHECK_NO_STOP(mstrCtrl)    (0u != ((mstrCtrl) & Temp_Sensor_MODE_NO_STOP))

/* Send read or write completion depends on state */
#define Temp_Sensor_GET_MSTAT_CMPLT ((0u != (Temp_Sensor_state & Temp_Sensor_SM_MSTR_RD)) ? \
                                                 (Temp_Sensor_MSTAT_RD_CMPLT) : (Temp_Sensor_MSTAT_WR_CMPLT))

/* Returns 7-bit slave address and used for software address match */
#define Temp_Sensor_GET_SLAVE_ADDR(dataReg)   (((dataReg) >> Temp_Sensor_SLAVE_ADDR_SHIFT) & \
                                                                  Temp_Sensor_SLAVE_ADDR_MASK)

#if(Temp_Sensor_FF_IMPLEMENTED)
    /* Check enable of module */
    #define Temp_Sensor_I2C_ENABLE_REG     (Temp_Sensor_ACT_PWRMGR_REG)
    #define Temp_Sensor_IS_I2C_ENABLE(reg) (0u != ((reg) & Temp_Sensor_ACT_PWR_EN))
    #define Temp_Sensor_IS_ENABLED         (0u != (Temp_Sensor_ACT_PWRMGR_REG & Temp_Sensor_ACT_PWR_EN))

    #define Temp_Sensor_CHECK_PWRSYS_I2C_BACKUP    (0u != (Temp_Sensor_PWRSYS_CR1_I2C_REG_BACKUP & \
                                                                Temp_Sensor_PWRSYS_CR1_REG))

    /* Check start condition generation */
    #define Temp_Sensor_CHECK_START_GEN(mcsr)  ((0u != ((mcsr) & Temp_Sensor_MCSR_START_GEN)) && \
                                                     (0u == ((mcsr) & Temp_Sensor_MCSR_MSTR_MODE)))

    #define Temp_Sensor_CLEAR_START_GEN        do{ \
                                                        Temp_Sensor_MCSR_REG &=                                   \
                                                                           ((uint8) ~Temp_Sensor_MCSR_START_GEN); \
                                                    }while(0)

    /* Stop interrupt */
    #define Temp_Sensor_ENABLE_INT_ON_STOP     do{ \
                                                        Temp_Sensor_CFG_REG |= Temp_Sensor_CFG_STOP_IE; \
                                                    }while(0)

    #define Temp_Sensor_DISABLE_INT_ON_STOP    do{ \
                                                        Temp_Sensor_CFG_REG &=                                 \
                                                                           ((uint8) ~Temp_Sensor_CFG_STOP_IE); \
                                                    }while(0)

    /* Transmit data */
    #define Temp_Sensor_TRANSMIT_DATA          do{ \
                                                        Temp_Sensor_CSR_REG = Temp_Sensor_CSR_TRANSMIT; \
                                                    }while(0)

    #define Temp_Sensor_ACK_AND_TRANSMIT       do{ \
                                                        Temp_Sensor_CSR_REG = (Temp_Sensor_CSR_ACK |      \
                                                                                    Temp_Sensor_CSR_TRANSMIT); \
                                                    }while(0)

    #define Temp_Sensor_NAK_AND_TRANSMIT       do{ \
                                                        Temp_Sensor_CSR_REG = Temp_Sensor_CSR_NAK; \
                                                    }while(0)

    /* Special case: udb needs to ack, ff needs to nak */
    #define Temp_Sensor_ACKNAK_AND_TRANSMIT    do{ \
                                                        Temp_Sensor_CSR_REG  = (Temp_Sensor_CSR_NAK |      \
                                                                                     Temp_Sensor_CSR_TRANSMIT); \
                                                    }while(0)
    /* Receive data */
    #define Temp_Sensor_ACK_AND_RECEIVE        do{ \
                                                        Temp_Sensor_CSR_REG = Temp_Sensor_CSR_ACK; \
                                                    }while(0)

    #define Temp_Sensor_NAK_AND_RECEIVE        do{ \
                                                        Temp_Sensor_CSR_REG = Temp_Sensor_CSR_NAK; \
                                                    }while(0)

    #define Temp_Sensor_READY_TO_READ          do{ \
                                                        Temp_Sensor_CSR_REG = Temp_Sensor_CSR_RDY_TO_RD; \
                                                    }while(0)

    /* Master condition generation */
    #define Temp_Sensor_GENERATE_START         do{ \
                                                        Temp_Sensor_MCSR_REG = Temp_Sensor_MCSR_START_GEN; \
                                                    }while(0)

    #if(CY_PSOC5A)
        #define Temp_Sensor_GENERATE_RESTART \
                        do{ \
                            Temp_Sensor_MCSR_REG = Temp_Sensor_MCSR_RESTART_GEN; \
                            Temp_Sensor_CSR_REG  = Temp_Sensor_CSR_NAK;          \
                        }while(0)

        #define Temp_Sensor_GENERATE_STOP      do{ \
                                                        Temp_Sensor_CSR_REG = Temp_Sensor_CSR_STOP_GEN; \
                                                    }while(0)

    #else   /* PSoC3 ES3 handlees zero lenght packets */
        #define Temp_Sensor_GENERATE_RESTART \
                        do{ \
                            Temp_Sensor_MCSR_REG = (Temp_Sensor_MCSR_RESTART_GEN | \
                                                         Temp_Sensor_MCSR_STOP_GEN);    \
                            Temp_Sensor_CSR_REG  = Temp_Sensor_CSR_TRANSMIT;       \
                        }while(0)

        #define Temp_Sensor_GENERATE_STOP \
                        do{ \
                            Temp_Sensor_MCSR_REG = Temp_Sensor_MCSR_STOP_GEN; \
                            Temp_Sensor_CSR_REG  = Temp_Sensor_CSR_TRANSMIT;  \
                        }while(0)
    #endif /* (CY_PSOC5A) */

    /* Master manual APIs compatible defines */
    #define Temp_Sensor_GENERATE_RESTART_MANUAL    Temp_Sensor_GENERATE_RESTART
    #define Temp_Sensor_GENERATE_STOP_MANUAL       Temp_Sensor_GENERATE_STOP
    #define Temp_Sensor_TRANSMIT_DATA_MANUAL       Temp_Sensor_TRANSMIT_DATA
    #define Temp_Sensor_READY_TO_READ_MANUAL       Temp_Sensor_READY_TO_READ
    #define Temp_Sensor_ACK_AND_RECEIVE_MANUAL     Temp_Sensor_ACK_AND_RECEIVE

#else

    /* Masks to enalbe interrupts from Status register */
    #define Temp_Sensor_STOP_IE_MASK           (Temp_Sensor_STS_STOP_MASK)
    #define Temp_Sensor_BYTE_COMPLETE_IE_MASK  (Temp_Sensor_STS_BYTE_COMPLETE_MASK)

    /* FF compatibility: CSR gegisters definitions */
    #define Temp_Sensor_CSR_LOST_ARB       (Temp_Sensor_STS_LOST_ARB_MASK)
    #define Temp_Sensor_CSR_STOP_STATUS    (Temp_Sensor_STS_STOP_MASK)
    #define Temp_Sensor_CSR_BUS_ERROR      (0x00u)
    #define Temp_Sensor_CSR_ADDRESS        (Temp_Sensor_STS_ADDR_MASK)
    #define Temp_Sensor_CSR_TRANSMIT       (Temp_Sensor_CTRL_TRANSMIT_MASK)
    #define Temp_Sensor_CSR_LRB            (Temp_Sensor_STS_LRB_MASK)
    #define Temp_Sensor_CSR_LRB_NAK        (Temp_Sensor_STS_LRB_MASK)
    #define Temp_Sensor_CSR_LRB_ACK        (0x00u)
    #define Temp_Sensor_CSR_BYTE_COMPLETE  (Temp_Sensor_STS_BYTE_COMPLETE_MASK)

    /* FF compatibility: MCSR gegisters definitions */
    #define Temp_Sensor_MCSR_REG           (Temp_Sensor_CSR_REG)   /* UDB incoporates master and slave regs */
    #define Temp_Sensor_MCSR_BUS_BUSY      (Temp_Sensor_STS_BUSY_MASK)       /* Is bus is busy              */
    #define Temp_Sensor_MCSR_START_GEN     (Temp_Sensor_CTRL_START_MASK)     /* Generate Sart condition     */
    #define Temp_Sensor_MCSR_RESTART_GEN   (Temp_Sensor_CTRL_RESTART_MASK)   /* Generates RESTART condition */
    #define Temp_Sensor_MCSR_MSTR_MODE     (Temp_Sensor_STS_MASTER_MODE_MASK)/* Define if active Master     */

    /* Data to write into TX FIFO to release FSM */
    #define Temp_Sensor_RELEASE_FSM         (0x00u)
    
    /* Check enable of module */
    #define Temp_Sensor_I2C_ENABLE_REG     (Temp_Sensor_CFG_REG)
    #define Temp_Sensor_IS_I2C_ENABLE(reg) ((0u != ((reg) & Temp_Sensor_ENABLE_MASTER)) || \
                                                 (0u != ((reg) & Temp_Sensor_ENABLE_SLAVE)))

    #define Temp_Sensor_IS_ENABLED         (0u != (Temp_Sensor_CFG_REG & Temp_Sensor_ENABLE_MS))

    /* Check start condition generation */
    #define Temp_Sensor_CHECK_START_GEN(mcsr)  ((0u != (Temp_Sensor_CFG_REG &        \
                                                             Temp_Sensor_MCSR_START_GEN)) \
                                                    &&                                         \
                                                    (0u == ((mcsr) & Temp_Sensor_MCSR_MSTR_MODE)))

    #define Temp_Sensor_CLEAR_START_GEN        do{ \
                                                        Temp_Sensor_CFG_REG &=                 \
                                                        ((uint8) ~Temp_Sensor_MCSR_START_GEN); \
                                                    }while(0)


    /* Stop interrupt */
    #define Temp_Sensor_ENABLE_INT_ON_STOP     do{ \
                                                       Temp_Sensor_INT_MASK_REG |= Temp_Sensor_STOP_IE_MASK; \
                                                    }while(0)

    #define Temp_Sensor_DISABLE_INT_ON_STOP    do{ \
                                                        Temp_Sensor_INT_MASK_REG &=                               \
                                                                             ((uint8) ~Temp_Sensor_STOP_IE_MASK); \
                                                    }while(0)


    /* Transmit data */
    #define Temp_Sensor_TRANSMIT_DATA      do{ \
                                                    Temp_Sensor_CFG_REG = (Temp_Sensor_CTRL_TRANSMIT_MASK | \
                                                                                Temp_Sensor_CTRL_DEFAULT);       \
                                                    Temp_Sensor_GO_REG  = Temp_Sensor_RELEASE_FSM;          \
                                                }while(0)

    #define Temp_Sensor_ACK_AND_TRANSMIT   Temp_Sensor_TRANSMIT_DATA


    #define Temp_Sensor_NAK_AND_TRANSMIT   do{ \
                                                    Temp_Sensor_CFG_REG = (Temp_Sensor_CTRL_NACK_MASK     | \
                                                                                Temp_Sensor_CTRL_TRANSMIT_MASK | \
                                                                                Temp_Sensor_CTRL_DEFAULT);       \
                                                    Temp_Sensor_GO_REG  =  Temp_Sensor_RELEASE_FSM;         \
                                                }while(0)

    /* Receive data */
    #define Temp_Sensor_READY_TO_READ      do{ \
                                                    Temp_Sensor_CFG_REG = Temp_Sensor_CTRL_DEFAULT; \
                                                    Temp_Sensor_GO_REG  =  Temp_Sensor_RELEASE_FSM; \
                                                }while(0)

    #define Temp_Sensor_ACK_AND_RECEIVE    Temp_Sensor_READY_TO_READ

    #define Temp_Sensor_NAK_AND_RECEIVE    do{ \
                                                    Temp_Sensor_CFG_REG = (Temp_Sensor_CTRL_NACK_MASK | \
                                                                                Temp_Sensor_CTRL_DEFAULT);   \
                                                    Temp_Sensor_GO_REG  =  Temp_Sensor_RELEASE_FSM;     \
                                                }while(0)

    /* Master condition generation */
    #define Temp_Sensor_GENERATE_START     do{ \
                                                    Temp_Sensor_CFG_REG = (Temp_Sensor_CTRL_START_MASK | \
                                                                                 Temp_Sensor_CTRL_DEFAULT);   \
                                                    Temp_Sensor_GO_REG  =  Temp_Sensor_RELEASE_FSM;      \
                                                }while(0)

    #define Temp_Sensor_GENERATE_RESTART   do{ \
                                                    Temp_Sensor_CFG_REG = (Temp_Sensor_CTRL_RESTART_MASK | \
                                                                                Temp_Sensor_CTRL_NACK_MASK    | \
                                                                                Temp_Sensor_CTRL_DEFAULT);      \
                                                    Temp_Sensor_GO_REG  =  Temp_Sensor_RELEASE_FSM;        \
                                                }while(0)


    #define Temp_Sensor_GENERATE_STOP      do{ \
                                                    Temp_Sensor_CFG_REG = (Temp_Sensor_CTRL_NACK_MASK | \
                                                                                Temp_Sensor_CTRL_STOP_MASK | \
                                                                                Temp_Sensor_CTRL_DEFAULT);   \
                                                    Temp_Sensor_GO_REG  =  Temp_Sensor_RELEASE_FSM;     \
                                                }while(0)

    /* Master manual APIs compatible defines */
    /* These defines wait while byte complete is cleared after command issued */
    #define Temp_Sensor_GENERATE_RESTART_MANUAL    \
                                        do{             \
                                            Temp_Sensor_GENERATE_RESTART;                                    \
                                            while(Temp_Sensor_CHECK_BYTE_COMPLETE(Temp_Sensor_CSR_REG)) \
                                            {                                                                     \
                                                ; /* Wait when byte complete is cleared */                        \
                                            }                                                                     \
                                        }while(0)

    #define Temp_Sensor_GENERATE_STOP_MANUAL   \
                                        do{         \
                                            Temp_Sensor_GENERATE_STOP;                                       \
                                            while(Temp_Sensor_CHECK_BYTE_COMPLETE(Temp_Sensor_CSR_REG)) \
                                            {                                                                     \
                                                ; /* Wait when byte complete is cleared */                        \
                                            }                                                                     \
                                        }while(0)

    #define Temp_Sensor_TRANSMIT_DATA_MANUAL   \
                                        do{         \
                                            Temp_Sensor_TRANSMIT_DATA;                                       \
                                            while(Temp_Sensor_CHECK_BYTE_COMPLETE(Temp_Sensor_CSR_REG)) \
                                            {                                                                     \
                                                ; /* Wait when byte complete is cleared */                        \
                                            }                                                                     \
                                        }while(0)

    #define Temp_Sensor_READY_TO_READ_MANUAL   \
                                        do{         \
                                            Temp_Sensor_READY_TO_READ;      \
                                            while(Temp_Sensor_CHECK_BYTE_COMPLETE(Temp_Sensor_CSR_REG)) \
                                            {                                                                     \
                                                ; /* Wait when byte complete is cleared */                        \
                                            }                                                                     \
                                        }while(0)

    #define Temp_Sensor_ACK_AND_RECEIVE_MANUAL \
                                        do{         \
                                            Temp_Sensor_ACK_AND_RECEIVE;                                     \
                                            while(Temp_Sensor_CHECK_BYTE_COMPLETE(Temp_Sensor_CSR_REG)) \
                                            {                                                                     \
                                                ; /* Wait when byte complete is cleared */                        \
                                            }                                                                     \
                                        }while(0)
#endif /* (Temp_Sensor_FF_IMPLEMENTED) */

/* Comon for FF and UDB: used to release bus after lost arb */
#define Temp_Sensor_BUS_RELEASE    Temp_Sensor_READY_TO_READ


/***************************************
*     Default register init constants
***************************************/

#define Temp_Sensor_DISABLE    (0u)
#define Temp_Sensor_ENABLE     (1u)

#if(Temp_Sensor_FF_IMPLEMENTED)
    /* Temp_Sensor_XCFG_REG: bits definition */
    #define Temp_Sensor_DEFAULT_XCFG_HW_ADDR_EN ((Temp_Sensor_HW_ADRR_DECODE) ? \
                                                        (Temp_Sensor_XCFG_HDWR_ADDR_EN) : (0u))

    #define Temp_Sensor_DEFAULT_XCFG_I2C_ON    ((Temp_Sensor_WAKEUP_ENABLED) ? \
                                                        (Temp_Sensor_XCFG_I2C_ON) : (0u))


    #define Temp_Sensor_DEFAULT_CFG_SIO_SELECT ((Temp_Sensor_I2C1_SIO_PAIR) ? \
                                                        (Temp_Sensor_CFG_SIO_SELECT) : (0u))


    /* Temp_Sensor_CFG_REG: bits definition */
    #define Temp_Sensor_DEFAULT_CFG_PSELECT    ((Temp_Sensor_WAKEUP_ENABLED) ? \
                                                        (Temp_Sensor_CFG_PSELECT) : (0u))

    #define Temp_Sensor_DEFAULT_CLK_RATE0  ((Temp_Sensor_DATA_RATE <= 50u) ?        \
                                                    (Temp_Sensor_CFG_CLK_RATE_050) :     \
                                                    ((Temp_Sensor_DATA_RATE <= 100u) ?   \
                                                        (Temp_Sensor_CFG_CLK_RATE_100) : \
                                                        (Temp_Sensor_CFG_CLK_RATE_400)))

    #define Temp_Sensor_DEFAULT_CLK_RATE1  ((Temp_Sensor_DATA_RATE <= 50u) ?           \
                                                 (Temp_Sensor_CFG_CLK_RATE_LESS_EQUAL_50) : \
                                                 (Temp_Sensor_CFG_CLK_RATE_GRATER_50))

    #define Temp_Sensor_DEFAULT_CLK_RATE   ((CY_PSOC5A) ? (Temp_Sensor_DEFAULT_CLK_RATE0) : \
                                                               (Temp_Sensor_DEFAULT_CLK_RATE1))


    #define Temp_Sensor_ENABLE_MASTER      ((Temp_Sensor_MODE_MASTER_ENABLED) ? \
                                                 (Temp_Sensor_CFG_EN_MSTR) : (0u))

    #define Temp_Sensor_ENABLE_SLAVE       ((Temp_Sensor_MODE_SLAVE_ENABLED) ? \
                                                 (Temp_Sensor_CFG_EN_SLAVE) : (0u))

    #define Temp_Sensor_ENABLE_MS      (Temp_Sensor_ENABLE_MASTER | Temp_Sensor_ENABLE_SLAVE)


    /* Temp_Sensor_DEFAULT_XCFG_REG */
    #define Temp_Sensor_DEFAULT_XCFG   (Temp_Sensor_XCFG_CLK_EN         | \
                                             Temp_Sensor_DEFAULT_XCFG_I2C_ON | \
                                             Temp_Sensor_DEFAULT_XCFG_HW_ADDR_EN)

    /* Temp_Sensor_DEFAULT_CFG_REG */
    #define Temp_Sensor_DEFAULT_CFG    (Temp_Sensor_DEFAULT_CFG_SIO_SELECT | \
                                             Temp_Sensor_DEFAULT_CFG_PSELECT    | \
                                             Temp_Sensor_DEFAULT_CLK_RATE       | \
                                             Temp_Sensor_ENABLE_MASTER          | \
                                             Temp_Sensor_ENABLE_SLAVE)

    /*Temp_Sensor_DEFAULT_DIVIDE_FACTOR_REG */
    #define Temp_Sensor_DEFAULT_DIVIDE_FACTOR  ((CY_PSOC5A) ? ((uint8) 4u) : ((uint16) 15u))

#else
    /* Temp_Sensor_CFG_REG: bits definition  */
    #define Temp_Sensor_ENABLE_MASTER  ((Temp_Sensor_MODE_MASTER_ENABLED) ? \
                                             (Temp_Sensor_CTRL_ENABLE_MASTER_MASK) : (0u))

    #define Temp_Sensor_ENABLE_SLAVE   ((Temp_Sensor_MODE_SLAVE_ENABLED) ? \
                                             (Temp_Sensor_CTRL_ENABLE_SLAVE_MASK) : (0u))

    #define Temp_Sensor_ENABLE_MS      (Temp_Sensor_ENABLE_MASTER | Temp_Sensor_ENABLE_SLAVE)


    #define Temp_Sensor_DEFAULT_CTRL_ANY_ADDR   ((Temp_Sensor_HW_ADRR_DECODE) ? \
                                                      (0u) : (Temp_Sensor_CTRL_ANY_ADDRESS_MASK))

    /* Temp_Sensor_DEFAULT_CFG_REG */
    #define Temp_Sensor_DEFAULT_CFG    (Temp_Sensor_DEFAULT_CTRL_ANY_ADDR)

    /* All CTRL default bits to be used in macro */
    #define Temp_Sensor_CTRL_DEFAULT   (Temp_Sensor_DEFAULT_CTRL_ANY_ADDR | Temp_Sensor_ENABLE_MS)

    /* Master clock generator: d0 and d1 */
    #define Temp_Sensor_MCLK_PERIOD_VALUE  (0x0Fu)
    #define Temp_Sensor_MCLK_COMPARE_VALUE (0x08u)

    /* Slave bit-counter: contorol period */
    #define Temp_Sensor_PERIOD_VALUE       (0x07u)

    /* Temp_Sensor_DEFAULT_INT_MASK */
    #define Temp_Sensor_DEFAULT_INT_MASK   (Temp_Sensor_BYTE_COMPLETE_IE_MASK)

    /* Temp_Sensor_DEFAULT_MCLK_PRD_REG */
    #define Temp_Sensor_DEFAULT_MCLK_PRD   (Temp_Sensor_MCLK_PERIOD_VALUE)

    /* Temp_Sensor_DEFAULT_MCLK_CMP_REG */
    #define Temp_Sensor_DEFAULT_MCLK_CMP   (Temp_Sensor_MCLK_COMPARE_VALUE)

    /* Temp_Sensor_DEFAULT_PERIOD_REG */
    #define Temp_Sensor_DEFAULT_PERIOD     (Temp_Sensor_PERIOD_VALUE)

#endif /* (Temp_Sensor_FF_IMPLEMENTED) */


/***************************************
*       Obsolete
***************************************/

/* Following code are OBSOLETE and must not be used 
 * starting from I2C 3.20
 */
 
#define Temp_Sensor_SSTAT_RD_ERR       (0x08u)
#define Temp_Sensor_SSTAT_WR_ERR       (0x80u)
#define Temp_Sensor_MSTR_SLAVE_BUSY    (Temp_Sensor_MSTR_NOT_READY)
#define Temp_Sensor_MSTAT_ERR_BUF_OVFL (0x80u)
#define Temp_Sensor_SSTAT_RD_CMPT      (Temp_Sensor_SSTAT_RD_CMPLT)
#define Temp_Sensor_SSTAT_WR_CMPT      (Temp_Sensor_SSTAT_WR_CMPLT)
#define Temp_Sensor_MODE_MULTI_MASTER_ENABLE    (Temp_Sensor_MODE_MULTI_MASTER_MASK)
#define Temp_Sensor_DATA_RATE_50       (50u)
#define Temp_Sensor_DATA_RATE_100      (100u)
#define Temp_Sensor_DEV_MASK           (0xF0u)
#define Temp_Sensor_SM_SL_STOP         (0x14u)
#define Temp_Sensor_SM_MASTER_IDLE     (0x40u)
#define Temp_Sensor_HDWR_DECODE        (0x01u)

#endif /* CY_I2C_Temp_Sensor_H */


/* [] END OF FILE */
