/*******************************************************************************
* File Name: BT_NC.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <BT_NC.H>

#if !defined(BT_NC__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START BT_NC_intc` */
extern uint8 NC;
/* `#END` */


/*******************************************************************************
* Function Name: BT_NC_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void BT_NC_Start(void) 
{
    /* For all we know the interrupt is active. */
    BT_NC_Disable();

    /* Set the ISR to point to the BT_NC Interrupt. */
    BT_NC_SetVector(&BT_NC_Interrupt);

    /* Set the priority. */
    BT_NC_SetPriority((uint8)BT_NC_INTC_PRIOR_NUMBER);

    /* Enable it. */
    BT_NC_Enable();
}


/*******************************************************************************
* Function Name: BT_NC_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void BT_NC_StartEx(cyisraddress address) 
{
    /* For all we know the interrupt is active. */
    BT_NC_Disable();

    /* Set the ISR to point to the BT_NC Interrupt. */
    BT_NC_SetVector(address);

    /* Set the priority. */
    BT_NC_SetPriority((uint8)BT_NC_INTC_PRIOR_NUMBER);

    /* Enable it. */
    BT_NC_Enable();
}


/*******************************************************************************
* Function Name: BT_NC_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void BT_NC_Stop(void) 
{
    /* Disable this interrupt. */
    BT_NC_Disable();
}


/*******************************************************************************
* Function Name: BT_NC_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for BT_NC.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(BT_NC_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START BT_NC_Interrupt` */
    NC = 1;
    /* `#END` */

    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3)
        #if((CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2) && (BT_NC__ES2_PATCH ))      
            BT_NC_ISR_PATCH();
        #endif /* CYDEV_CHIP_REVISION_USED */
    #endif /* (CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3) */
}


/*******************************************************************************
* Function Name: BT_NC_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling BT_NC_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use BT_NC_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void BT_NC_SetVector(cyisraddress address) 
{
    CY_SET_REG16(BT_NC_INTC_VECTOR, (uint16) address);
}


/*******************************************************************************
* Function Name: BT_NC_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress BT_NC_GetVector(void) 
{
    return (cyisraddress) CY_GET_REG16(BT_NC_INTC_VECTOR);
}


/*******************************************************************************
* Function Name: BT_NC_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling BT_NC_Start
*   or BT_NC_StartEx will override any effect this method would 
*   have had. This method should only be called after BT_NC_Start or 
*   BT_NC_StartEx has been called. To set the initial
*   priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void BT_NC_SetPriority(uint8 priority) 
{
    *BT_NC_INTC_PRIOR = priority << 5;
}


/*******************************************************************************
* Function Name: BT_NC_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*******************************************************************************/
uint8 BT_NC_GetPriority(void) 
{
    uint8 priority;


    priority = *BT_NC_INTC_PRIOR >> 5;

    return priority;
}


/*******************************************************************************
* Function Name: BT_NC_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void BT_NC_Enable(void) 
{
    /* Enable the general interrupt. */
    *BT_NC_INTC_SET_EN = BT_NC__INTC_MASK;
}


/*******************************************************************************
* Function Name: BT_NC_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 BT_NC_GetState(void) 
{
    /* Get the state of the general interrupt. */
    return ((*BT_NC_INTC_SET_EN & (uint8)BT_NC__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: BT_NC_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void BT_NC_Disable(void) 
{
    /* Disable the general interrupt. */
    *BT_NC_INTC_CLR_EN = BT_NC__INTC_MASK;
}


/*******************************************************************************
* Function Name: BT_NC_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void BT_NC_SetPending(void) 
{
    *BT_NC_INTC_SET_PD = BT_NC__INTC_MASK;
}


/*******************************************************************************
* Function Name: BT_NC_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void BT_NC_ClearPending(void) 
{
    *BT_NC_INTC_CLR_PD = BT_NC__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
