/*******************************************************************************
* File Name: Bluetooth_PM.c
* Version 2.30
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "Bluetooth.h"


/***************************************
* Local data allocation
***************************************/

static Bluetooth_BACKUP_STRUCT  Bluetooth_backup =
{
    /* enableState - disabled */
    0u,
};



/*******************************************************************************
* Function Name: Bluetooth_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  Bluetooth_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void Bluetooth_SaveConfig(void)
{
    #if (CY_UDB_V0)

        #if(Bluetooth_CONTROL_REG_REMOVED == 0u)
            Bluetooth_backup.cr = Bluetooth_CONTROL_REG;
        #endif /* End Bluetooth_CONTROL_REG_REMOVED */

        #if( (Bluetooth_RX_ENABLED) || (Bluetooth_HD_ENABLED) )
            Bluetooth_backup.rx_period = Bluetooth_RXBITCTR_PERIOD_REG;
            Bluetooth_backup.rx_mask = Bluetooth_RXSTATUS_MASK_REG;
            #if (Bluetooth_RXHW_ADDRESS_ENABLED)
                Bluetooth_backup.rx_addr1 = Bluetooth_RXADDRESS1_REG;
                Bluetooth_backup.rx_addr2 = Bluetooth_RXADDRESS2_REG;
            #endif /* End Bluetooth_RXHW_ADDRESS_ENABLED */
        #endif /* End Bluetooth_RX_ENABLED | Bluetooth_HD_ENABLED*/

        #if(Bluetooth_TX_ENABLED)
            #if(Bluetooth_TXCLKGEN_DP)
                Bluetooth_backup.tx_clk_ctr = Bluetooth_TXBITCLKGEN_CTR_REG;
                Bluetooth_backup.tx_clk_compl = Bluetooth_TXBITCLKTX_COMPLETE_REG;
            #else
                Bluetooth_backup.tx_period = Bluetooth_TXBITCTR_PERIOD_REG;
            #endif /*End Bluetooth_TXCLKGEN_DP */
            Bluetooth_backup.tx_mask = Bluetooth_TXSTATUS_MASK_REG;
        #endif /*End Bluetooth_TX_ENABLED */


    #else /* CY_UDB_V1 */

        #if(Bluetooth_CONTROL_REG_REMOVED == 0u)
            Bluetooth_backup.cr = Bluetooth_CONTROL_REG;
        #endif /* End Bluetooth_CONTROL_REG_REMOVED */

    #endif  /* End CY_UDB_V0 */
}


/*******************************************************************************
* Function Name: Bluetooth_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  Bluetooth_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void Bluetooth_RestoreConfig(void)
{

    #if (CY_UDB_V0)

        #if(Bluetooth_CONTROL_REG_REMOVED == 0u)
            Bluetooth_CONTROL_REG = Bluetooth_backup.cr;
        #endif /* End Bluetooth_CONTROL_REG_REMOVED */

        #if( (Bluetooth_RX_ENABLED) || (Bluetooth_HD_ENABLED) )
            Bluetooth_RXBITCTR_PERIOD_REG = Bluetooth_backup.rx_period;
            Bluetooth_RXSTATUS_MASK_REG = Bluetooth_backup.rx_mask;
            #if (Bluetooth_RXHW_ADDRESS_ENABLED)
                Bluetooth_RXADDRESS1_REG = Bluetooth_backup.rx_addr1;
                Bluetooth_RXADDRESS2_REG = Bluetooth_backup.rx_addr2;
            #endif /* End Bluetooth_RXHW_ADDRESS_ENABLED */
        #endif  /* End (Bluetooth_RX_ENABLED) || (Bluetooth_HD_ENABLED) */

        #if(Bluetooth_TX_ENABLED)
            #if(Bluetooth_TXCLKGEN_DP)
                Bluetooth_TXBITCLKGEN_CTR_REG = Bluetooth_backup.tx_clk_ctr;
                Bluetooth_TXBITCLKTX_COMPLETE_REG = Bluetooth_backup.tx_clk_compl;
            #else
                Bluetooth_TXBITCTR_PERIOD_REG = Bluetooth_backup.tx_period;
            #endif /*End Bluetooth_TXCLKGEN_DP */
            Bluetooth_TXSTATUS_MASK_REG = Bluetooth_backup.tx_mask;
        #endif /*End Bluetooth_TX_ENABLED */

    #else /* CY_UDB_V1 */

        #if(Bluetooth_CONTROL_REG_REMOVED == 0u)
            Bluetooth_CONTROL_REG = Bluetooth_backup.cr;
        #endif /* End Bluetooth_CONTROL_REG_REMOVED */

    #endif  /* End CY_UDB_V0 */
}


/*******************************************************************************
* Function Name: Bluetooth_Sleep
********************************************************************************
*
* Summary:
*  Stops and saves the user configuration. Should be called
*  just prior to entering sleep.
*
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  Bluetooth_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void Bluetooth_Sleep(void)
{

    #if(Bluetooth_RX_ENABLED || Bluetooth_HD_ENABLED)
        if((Bluetooth_RXSTATUS_ACTL_REG  & Bluetooth_INT_ENABLE) != 0u)
        {
            Bluetooth_backup.enableState = 1u;
        }
        else
        {
            Bluetooth_backup.enableState = 0u;
        }
    #else
        if((Bluetooth_TXSTATUS_ACTL_REG  & Bluetooth_INT_ENABLE) !=0u)
        {
            Bluetooth_backup.enableState = 1u;
        }
        else
        {
            Bluetooth_backup.enableState = 0u;
        }
    #endif /* End Bluetooth_RX_ENABLED || Bluetooth_HD_ENABLED*/

    Bluetooth_Stop();
    Bluetooth_SaveConfig();
}


/*******************************************************************************
* Function Name: Bluetooth_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  Bluetooth_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void Bluetooth_Wakeup(void)
{
    Bluetooth_RestoreConfig();
    #if( (Bluetooth_RX_ENABLED) || (Bluetooth_HD_ENABLED) )
        Bluetooth_ClearRxBuffer();
    #endif /* End (Bluetooth_RX_ENABLED) || (Bluetooth_HD_ENABLED) */
    #if(Bluetooth_TX_ENABLED || Bluetooth_HD_ENABLED)
        Bluetooth_ClearTxBuffer();
    #endif /* End Bluetooth_TX_ENABLED || Bluetooth_HD_ENABLED */

    if(Bluetooth_backup.enableState != 0u)
    {
        Bluetooth_Enable();
    }
}


/* [] END OF FILE */
