/*******************************************************************************
* File Name: Left.c  
* Version 1.80
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Left.h"


/*******************************************************************************
* Function Name: Left_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Left_Write(uint8 value) 
{
    uint8 staticBits = (Left_DR & (uint8)(~Left_MASK));
    Left_DR = staticBits | ((uint8)(value << Left_SHIFT) & Left_MASK);
}


/*******************************************************************************
* Function Name: Left_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void Left_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Left_0, mode);
}


/*******************************************************************************
* Function Name: Left_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Left_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Left_Read(void) 
{
    return (Left_PS & Left_MASK) >> Left_SHIFT;
}


/*******************************************************************************
* Function Name: Left_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Left_ReadDataReg(void) 
{
    return (Left_DR & Left_MASK) >> Left_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Left_INTSTAT) 

    /*******************************************************************************
    * Function Name: Left_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Left_ClearInterrupt(void) 
    {
        return (Left_INTSTAT & Left_MASK) >> Left_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
