/*******************************************************************************
* File Name: NC_RESET.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "NC_RESET.h"


/*******************************************************************************
* Function Name: NC_RESET_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void NC_RESET_Write(uint8 value) 
{
    uint8 staticBits = (NC_RESET_DR & (uint8)(~NC_RESET_MASK));
    NC_RESET_DR = staticBits | ((uint8)(value << NC_RESET_SHIFT) & NC_RESET_MASK);
}


/*******************************************************************************
* Function Name: NC_RESET_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void NC_RESET_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(NC_RESET_0, mode);
}


/*******************************************************************************
* Function Name: NC_RESET_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro NC_RESET_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 NC_RESET_Read(void) 
{
    return (NC_RESET_PS & NC_RESET_MASK) >> NC_RESET_SHIFT;
}


/*******************************************************************************
* Function Name: NC_RESET_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 NC_RESET_ReadDataReg(void) 
{
    return (NC_RESET_DR & NC_RESET_MASK) >> NC_RESET_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(NC_RESET_INTSTAT) 

    /*******************************************************************************
    * Function Name: NC_RESET_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 NC_RESET_ClearInterrupt(void) 
    {
        return (NC_RESET_INTSTAT & NC_RESET_MASK) >> NC_RESET_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
